.. _Contributing:

Contributing
============

.. toctree::
   :maxdepth: 2
   :caption: Contributing
   :hidden:

   code-of-conduct
   ways-to-contribute

Thank you for your interest in imitation!

As an open-source project, we welcome contributions from all users, and are always open to any feedback or suggestions. This section of the documentation is intended to help you understand the process of contributing to the project.


To keep the community open and inclusive, we have developed a :ref:`Code of Conduct <Code of Conduct>`. If you are not
familiar with our Code of Conduct, take a minute to read it before starting your first contribution.
